[SCM] WebKit Debian packaging branch, webkit-1.1, updated. upstream/1.1.16-1409-g5afdf4d

eric at webkit.org eric at webkit.org
Thu Dec 3 13:24:19 UTC 2009


The following commit has been merged in the webkit-1.1 branch:
commit a7f8293c93abcee73fd44825c10a7bf2f1546950
Author: eric at webkit.org <eric at webkit.org@268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Sun Nov 1 21:38:52 2009 +0000

    2009-11-01  Yael Aharon  <yael.aharon at nokia.com>
    
            Reviewed by Darin Adler.
    
            Don't add '/' to the URL path if the it does not include '/' after the protocol component
            https://bugs.webkit.org/show_bug.cgi?id=30971
    
            Updating the expected result to reflect the change.
    
            * fast/loader/url-parse-1-expected.txt:
    2009-11-01  Yael Aharon  <yael.aharon at nokia.com>
    
            Reviewed by Darin Adler.
    
            Don't add '/' to the URL path if the it does not include '/' after the protocol component
            https://bugs.webkit.org/show_bug.cgi?id=30971
    
            Match IE8 behaviour, that does not add '/' if there is none after the protocol component.
    
            * platform/KURL.cpp:
            (WebCore::KURL::parse):
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@50395 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/LayoutTests/ChangeLog b/LayoutTests/ChangeLog
index df0a093..47ce1b2 100644
--- a/LayoutTests/ChangeLog
+++ b/LayoutTests/ChangeLog
@@ -1,3 +1,14 @@
+2009-11-01  Yael Aharon  <yael.aharon at nokia.com>
+
+        Reviewed by Darin Adler.
+
+        Don't add '/' to the URL path if the it does not include '/' after the protocol component
+        https://bugs.webkit.org/show_bug.cgi?id=30971
+
+        Updating the expected result to reflect the change.
+
+        * fast/loader/url-parse-1-expected.txt:
+
 2009-10-31  Alexey Proskuryakov  <ap at apple.com>
 
         Reviewed by John Sullivan.
diff --git a/LayoutTests/fast/loader/url-parse-1-expected.txt b/LayoutTests/fast/loader/url-parse-1-expected.txt
index 81aab7d..33ea5a7 100644
--- a/LayoutTests/fast/loader/url-parse-1-expected.txt
+++ b/LayoutTests/fast/loader/url-parse-1-expected.txt
@@ -20,7 +20,7 @@ file:///test	file:///test		/test
 file://localhost	file:		
 file://localhost/	file:///		/
 file://localhost/test	file:///test		/test
-http:	http:/		/
+http:	http:		
 http:/	http:/		/
 http://	http:/		/
 http:///	http:/		/
diff --git a/WebCore/ChangeLog b/WebCore/ChangeLog
index 77adf42..579476b 100644
--- a/WebCore/ChangeLog
+++ b/WebCore/ChangeLog
@@ -1,3 +1,15 @@
+2009-11-01  Yael Aharon  <yael.aharon at nokia.com>
+
+        Reviewed by Darin Adler.
+
+        Don't add '/' to the URL path if the it does not include '/' after the protocol component
+        https://bugs.webkit.org/show_bug.cgi?id=30971
+
+        Match IE8 behaviour, that does not add '/' if there is none after the protocol component.
+
+        * platform/KURL.cpp:
+        (WebCore::KURL::parse):
+
 2009-10-31  Oliver Hunt  <oliver at apple.com>
 
         Reviewed by Darin Adler.
diff --git a/WebCore/platform/KURL.cpp b/WebCore/platform/KURL.cpp
index ffacc19..c5829d2 100644
--- a/WebCore/platform/KURL.cpp
+++ b/WebCore/platform/KURL.cpp
@@ -1269,8 +1269,8 @@ void KURL::parse(const char* url, const String* originalString)
         m_userStart = m_userEnd = m_passwordEnd = m_hostEnd = m_portEnd = p - buffer.data();
 
     // For canonicalization, ensure we have a '/' for no path.
-    // Only do this for http and https.
-    if (m_protocolInHTTPFamily && pathEnd - pathStart == 0)
+    // Do this only for hierarchical URL with protocol http or https.
+    if (m_protocolInHTTPFamily && hierarchical && pathEnd == pathStart)
         *p++ = '/';
 
     // add path, escaping bad characters

-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list